<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR" sourcelanguage="en_GB">
<context>
    <name>About</name>
    <message>
        <source>About Cppcheck</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Cppcheck - A tool for static C/C++ code analysis.</source>
        <translation>Cppcheck - Un outil d&apos;analyse statique de code C/C++.</translation>
    </message>
    <message>
        <source>This program is licensed under the terms
of the GNU General Public License version 3</source>
        <translation>Ce programme est sous license GNU
General Public License version 3</translation>
    </message>
    <message>
        <source>Visit Cppcheck homepage at %1</source>
        <translation>Visitez le site Cppcheck : %1</translation>
    </message>
    <message utf8="true">
        <source>Copyright © 2007-2013 Daniel Marjamäki and cppcheck team.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationDialog</name>
    <message>
        <source>Add an application</source>
        <translation>Ajouter une application</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <source>Executable files (*.exe);;All files(*.*)</source>
        <translation>Fichier exécutable (*.exe);;Tous les fichiers(*.*)</translation>
    </message>
    <message>
        <source>Select viewer application</source>
        <translation>Sélection de l&apos;application</translation>
    </message>
    <message>
        <source>Cppcheck</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Executable:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Parameters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can add an application that can open error files. Specify a name for the application, the application executable and command line parameters for the application.

The following texts in parameters are replaced with appropriate values when application is executed:
(file) - Filename containing the error
(line) - Line number containing the error
(message) - Error message
(severity) - Error severity

Example opening a file with Kate and make Kate scroll to the correct line:
Executable: kate
Parameters: -l(line) (file)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a name, a path and optionally parameters for the application!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileViewDialog</name>
    <message>
        <source>Could not find the file: %1</source>
        <translation type="unfinished">Ne trouve pas le fichier : %1</translation>
    </message>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not read the file: %1</source>
        <translation type="unfinished">Ne peut pas lire le fichier : %1</translation>
    </message>
</context>
<context>
    <name>LogView</name>
    <message>
        <source>Checking Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text files (*.txt *.log);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not open file for writing: &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished">&amp;Affichage</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation type="unfinished">&amp;Vérifier</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Édition</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation type="unfinished">Standard</translation>
    </message>
    <message>
        <source>&amp;License...</source>
        <translation type="unfinished">&amp;License...</translation>
    </message>
    <message>
        <source>A&amp;uthors...</source>
        <translation type="unfinished">A&amp;uteur...</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation type="unfinished">À &amp;Propos...</translation>
    </message>
    <message>
        <source>&amp;Files...</source>
        <translation type="unfinished">&amp;Fichiers...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Directory...</source>
        <translation type="unfinished">&amp;Répertoires...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Recheck files</source>
        <translation type="unfinished">&amp;Revérifier les fichiers</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="unfinished">&amp;Arrêter</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save results to file...</source>
        <translation type="unfinished">&amp;Sauvegarder les résultats dans un fichier...</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Clear results</source>
        <translation type="unfinished">&amp;Effacer les résultats</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="unfinished">&amp;Préférences</translation>
    </message>
    <message>
        <source>&amp;Check all</source>
        <translation type="unfinished">Tout &amp;cocher</translation>
    </message>
    <message>
        <source>&amp;Uncheck all</source>
        <translation type="unfinished">Tout &amp;décocher</translation>
    </message>
    <message>
        <source>Collapse &amp;all</source>
        <translation type="unfinished">Tout &amp;réduire</translation>
    </message>
    <message>
        <source>&amp;Expand all</source>
        <translation type="unfinished">Tout &amp;afficher</translation>
    </message>
    <message>
        <source>&amp;Contents</source>
        <translation type="unfinished">&amp;Contenu</translation>
    </message>
    <message>
        <source>Open the help contents</source>
        <translation type="unfinished">Ouvir l&apos;aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No suitable files found to check!</source>
        <translation type="unfinished">Pas de fichiers trouvés !</translation>
    </message>
    <message>
        <source>Select directory to check</source>
        <translation type="unfinished">Sélectionner le répertoire à vérifier</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished">Licence</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished">Auteur</translation>
    </message>
    <message>
        <source>Save the report file</source>
        <translation type="unfinished">Sauvegarder le rapport</translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation type="unfinished">Fichier XML (*.xml)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation type="unfinished">Fichier Texte  (*.txt)</translation>
    </message>
    <message>
        <source>CSV files (*.csv)</source>
        <translation type="unfinished">Fichier CSV (*.csv)</translation>
    </message>
    <message>
        <source>Cppcheck - %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>English</source>
        <translation type="unfinished">Anglais</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="unfinished">Hollandais</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="unfinished">Finlandais</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation type="unfinished">Suédois</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished">Allemand</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished">Russe</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show style warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Standard items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open XML...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open P&amp;roject File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Project File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Log View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose Project File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit Project File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Performance warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show performance warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show information messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show portability warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must close the project file before selecting new files or directories!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the report file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Checking is running.

Do you want to stop the checking and exit Cppcheck?.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files version 2 (*.xml);;XML files version 1 (*.xml);;Text files (*.txt);;CSV files (*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files version 1 (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files version 2 (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project files (*.cppcheck);;All files(*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Project File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Project Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No project file loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serbian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was a problem with loading the editor application settings.

This is probably because the settings were changed between the Cppcheck versions. Please check (and fix) the editor application settings, otherwise the editor program might not start correctly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quick Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found project file: %1

Do you want to load this project file instead?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found project files from the directory.

Do you want to proceed checking without using any of these project files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The project file

%1

 could not be found!

Do you want to remove the file from the recently used projects -list?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows 32-bit ANSI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows 32-bit Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unix 32-bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unix 64-bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows 64-bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platforms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C++11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C99</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current results will be cleared.

Opening a new XML file will clear current results.Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show S&amp;cratchpad...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chinese (Simplified)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select files to check</source>
        <translation type="unfinished">Sélectionner les fichiers à vérifier</translation>
    </message>
    <message>
        <source>Cppcheck GUI.

Syntax:
    cppcheck-gui [OPTIONS] [files or paths]

Options:
    -h, --help     Print this help
    -p &lt;file&gt;      Open given project file and start checking it
    -l &lt;file&gt;      Open given results xml file
    -d &lt;directory&gt; Specify the directory that was checked to generate the results xml specified with -l
    -v, --version  Show program version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cppcheck GUI - Command line parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C++ standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C89</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C++03</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Platforms</name>
    <message>
        <source>Unix 32-bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unix 64-bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows 32-bit ANSI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows 32-bit Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows 64-bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not read the project file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not write the project file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>Project File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defines:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Includes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include directories:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Root:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exclude</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProjectFileDialog</name>
    <message>
        <source>Project file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select include directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select directory to ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a directory to check</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Language file %1 not found!</source>
        <translation type="unfinished">Fichier de langue %1 non trouvé !</translation>
    </message>
    <message>
        <source>Failed to load translation for language %1 from file %2</source>
        <translation type="unfinished">Erreur lors du chargement de la langue %1 depuis le fichier %2</translation>
    </message>
    <message>
        <source>Unknown language specified!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultsTree</name>
    <message>
        <source>File</source>
        <translation type="unfinished">Fichier</translation>
    </message>
    <message>
        <source>Severity</source>
        <translation type="unfinished">Sévérité</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished">Ligne</translation>
    </message>
    <message>
        <source>Undefined file</source>
        <translation type="unfinished">Fichier indéterminé</translation>
    </message>
    <message>
        <source>Copy filename</source>
        <translation type="unfinished">Copier nom du fichier</translation>
    </message>
    <message>
        <source>Copy full path</source>
        <translation type="unfinished">Copier le chemin complet</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="unfinished">Copier le message</translation>
    </message>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not start %1

Please check the application path and parameters are correct.</source>
        <translation type="unfinished">Ne peut pas démarrer %1

Merci de vérifier que le chemin de l&apos;application et que les paramètres sont corrects.</translation>
    </message>
    <message>
        <source>style</source>
        <translation type="unfinished">erreur de style</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="unfinished">erreur</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not find the file!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not find file:
%1
Please select the directory where file is located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>portability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Inconclusive]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No editor application configured.

Configure the editor application for Cppcheck in preferences/Applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No default editor application selected.

Please select the default editor application in preferences/Applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy message id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide all with id</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultsView</name>
    <message>
        <source>Results</source>
        <translation type="unfinished">Résultats</translation>
    </message>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No errors found.</source>
        <translation type="unfinished">Pas d&apos;erreurs trouvées.</translation>
    </message>
    <message>
        <source>Errors were found, but they are configured to be hidden.
To toggle what kind of errors are shown, open view menu.</source>
        <translation type="unfinished">Des erreurs ont été trouvées mais sont configurées pour rester cachées
Pour configurer les erreurs affichées, ouvrez le menu d&apos;affichage.</translation>
    </message>
    <message>
        <source>No errors found, nothing to save.</source>
        <translation type="unfinished">Pas d&apos;erreurs trouvées, rien à sauvegarder.</translation>
    </message>
    <message>
        <source>Failed to save the report.</source>
        <translation type="unfinished">Erreur lors de la sauvegarde du rapport.</translation>
    </message>
    <message>
        <source>Failed to read the report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Message</translation>
    </message>
    <message>
        <source>%p% (%1 of %2 files checked)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScratchPad</name>
    <message>
        <source>Scratchpad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished">Préférences</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Général</translation>
    </message>
    <message>
        <source>Number of threads: </source>
        <translation type="unfinished">Nombre de processus : </translation>
    </message>
    <message>
        <source>Show full path of files</source>
        <translation type="unfinished">Montrer le chemin complet des fichiers</translation>
    </message>
    <message>
        <source>Show &quot;No errors found&quot; message when no errors found</source>
        <translation type="unfinished">Afficher un message &quot;Pas d&apos;erreur trouvée&quot; lorsque aucune erreur est trouvée</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished">Applications</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation type="unfinished">Rapports</translation>
    </message>
    <message>
        <source>Save all errors when creating report</source>
        <translation type="unfinished">Sauvegarder toutes les erreurs lorsqu&apos;un rapport est créé</translation>
    </message>
    <message>
        <source>Save full path to files in reports</source>
        <translation type="unfinished">Sauvegarder le chemin complet des fichiers dans les rapports</translation>
    </message>
    <message>
        <source>Include paths:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ideal count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force checking all #ifdef configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable inline suppressions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show inconclusive errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;how internal warnings in log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display error Id in column &quot;Id&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Add a new application</source>
        <translation type="unfinished">Ajouter une nouvelle application</translation>
    </message>
    <message>
        <source>Modify an application</source>
        <translation type="unfinished">Modifier une application</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select include directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Default]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include paths:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defines:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path Selected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of Files Scanned:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan Duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylistic warnings:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portability warnings:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Performance issues:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information messages:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.%1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> and </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of files scanned</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portability warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Performance warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information messages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThreadResult</name>
    <message>
        <source>%1 of %2 files checked</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TranslationHandler</name>
    <message>
        <source>Failed to change the user interface language:

%1

The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cppcheck</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TxtReport</name>
    <message>
        <source>inconclusive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
